import React, { useEffect, useMemo } from 'react'; // Fix import statement
import { SingleStackBarplot } from '@graphpolaris/shared/lib/components/charts/singleStackBarplot';
import ColumnedList from '@graphpolaris/shared/lib/components/columnListed/ColumnListed';
import { Button } from '../buttons';
import { Close } from '@mui/icons-material';

export type WelcomeDatabaseProps = {
  nodes: { name: string; value: number }[];
  edges: { name: string; value: number }[];
};

export const WelcomeDatabase = ({ nodes, edges }: WelcomeDatabaseProps) => {
  const sortedNodes = useMemo(() => [...nodes].sort((a, b) => b.value - a.value), [nodes]);
  const sortedEdges = useMemo(() => [...edges].sort((a, b) => b.value - a.value), [edges]);

  return (
    <div className="modal-box card flex gap-4 lg:min-w-[50rem] overflow-hidden">
      <div className="card-title flex justify-between ">
        <h1 className="text-xl font-bold">Database information:</h1>
        <Button rounded variant="ghost" iconComponent={<Close />} onClick={() => {}} />
      </div>
      <div className="nodesInformation">
        <div className="m-0 p-0">
          <h1 className="mx-7 font-medium text-secondary-700">Nodes Distribution</h1>
          <SingleStackBarplot title={'Nodes'} data={sortedNodes} />
        </div>
        <div className="my-2.2 ">
          <h1 className="mx-7 font-medium text-secondary-700">Nodes list</h1>
          <ColumnedList items={sortedNodes} maxHeight="300px" typePill="Nodes" />
        </div>
      </div>
      <div className="edgesInformation">
        <h1 className="mx-7 font-medium text-secondary-700">Edges Distribution</h1>
        <SingleStackBarplot title={'Edges'} data={sortedEdges} />
        <div className="my-2.2">
          <h1 className="mx-7 font-medium text-secondary-700">Edges list</h1>
          <ColumnedList items={sortedEdges} maxHeight="300px" typePill="Edges" />
        </div>
      </div>
    </div>
  );
};

export default WelcomeDatabase;
