import React from 'react';
import { Meta } from '@storybook/react';
import WelcomeDatabase, { WelcomeDatabaseProps } from '.';

const Component: Meta<typeof WelcomeDatabase> = {
  title: 'Components/WelcomeDatabase',
  component: WelcomeDatabase,
  decorators: [(story) => <div className="w-full h-screen flex flex-row justify-center">{story()}</div>],
};

export default Component;

export const smalMock = {
  args: {
    nodes: [
      { name: 'Order', value: 250 },
      { name: 'Supplier', value: 20 },
      { name: 'Product', value: 15 },
      { name: 'Customer', value: 15 },
    ],
    edges: [
      { name: 'CONNECTED_TO', value: 3, from: 'Order', to: 'Supplier' },
      { name: 'PART_OF', value: 7, from: 'Order', to: 'Customer' },
      { name: 'ORDERS', value: 2, from: 'Customer', to: 'Supplier' },
      { name: 'SUPPLIES', value: 5, from: 'Supplier', to: 'Product' },
    ],
  },
};

export const mediumMock = {
  args: {
    nodes: [
      { name: 'Order', value: 250 },
      { name: 'Supplier', value: 20 },
      { name: 'Product', value: 15 },
      { name: 'Customer', value: 15 },
      { name: 'Employee', value: 30 },
      { name: 'Manager', value: 25 },
      { name: 'Transaction', value: 100 },
      { name: 'Inventory', value: 50 },
      { name: 'Warehouse', value: 40 },
      { name: 'Delivery', value: 35 },
      { name: 'Category', value: 20 },
      { name: 'Payment', value: 45 },
      { name: 'Feedback', value: 10 },
      { name: 'Review', value: 5 },
      { name: 'Service', value: 30 },
    ],
    edges: [
      { name: 'CONNECTED_TO', value: 3, from: 'Order', to: 'Supplier' },
      { name: 'PART_OF', value: 7, from: 'Order', to: 'Customer' },
      { name: 'ORDERS', value: 2, from: 'Customer', to: 'Supplier' },
      { name: 'SUPPLIES', value: 5, from: 'Supplier', to: 'Product' },
      { name: 'RELATED_TO', value: 8, from: 'Order', to: 'Transaction' },
      { name: 'HAS', value: 6, from: 'Supplier', to: 'Inventory' },
      { name: 'WORKS_FOR', value: 4, from: 'Employee', to: 'Manager' },
      { name: 'MANAGES', value: 9, from: 'Manager', to: 'Employee' },
      { name: 'ASSOCIATED_WITH', value: 12, from: 'Product', to: 'Category' },
      { name: 'SERVES', value: 15, from: 'Warehouse', to: 'Delivery' },
      { name: 'PROVIDES', value: 18, from: 'Supplier', to: 'Service' },
      { name: 'USES', value: 20, from: 'Transaction', to: 'Service' },
      { name: 'MADE_OF', value: 25, from: 'Product', to: 'Inventory' },
      { name: 'SOLD_BY', value: 30, from: 'Product', to: 'Supplier' },
    ],
  },
};

export const largeMock = {
  args: {
    nodes: [
      { name: 'Order', value: 250 },
      { name: 'Supplier', value: 20 },
      { name: 'Product', value: 15 },
      { name: 'Customer', value: 15 },
      { name: 'Employee', value: 30 },
      { name: 'Manager', value: 25 },
      { name: 'Transaction', value: 100 },
      { name: 'Inventory', value: 50 },
      { name: 'Warehouse', value: 40 },
      { name: 'Delivery', value: 35 },
      { name: 'Category', value: 20 },
      { name: 'Payment', value: 45 },
      { name: 'Feedback', value: 10 },
      { name: 'Review', value: 5 },
      { name: 'Service', value: 30 },
      { name: 'Location', value: 40 },
      { name: 'Region', value: 35 },
      { name: 'Department', value: 25 },
      { name: 'Manufacturer', value: 30 },
      { name: 'Brand', value: 20 },
      { name: 'Contractor', value: 15 },
      { name: 'Provider', value: 25 },
      { name: 'Subscriber', value: 30 },
      { name: 'Recipient', value: 20 },
      { name: 'Agent', value: 10 },
    ],
    edges: [
      { name: 'CONNECTED_TO', value: 3, from: 'Order', to: 'Supplier' },
      { name: 'PART_OF', value: 7, from: 'Order', to: 'Customer' },
      { name: 'ORDERS', value: 2, from: 'Customer', to: 'Supplier' },
      { name: 'SUPPLIES', value: 5, from: 'Supplier', to: 'Product' },
      { name: 'RELATED_TO', value: 8, from: 'Order', to: 'Transaction' },
      { name: 'HAS', value: 6, from: 'Supplier', to: 'Inventory' },
      { name: 'WORKS_FOR', value: 4, from: 'Employee', to: 'Manager' },
      { name: 'MANAGES', value: 9, from: 'Manager', to: 'Employee' },
      { name: 'ASSOCIATED_WITH', value: 12, from: 'Product', to: 'Category' },
      { name: 'SERVES', value: 15, from: 'Warehouse', to: 'Delivery' },
      { name: 'PROVIDES', value: 18, from: 'Supplier', to: 'Service' },
      { name: 'USES', value: 20, from: 'Transaction', to: 'Service' },
      { name: 'MADE_OF', value: 25, from: 'Product', to: 'Inventory' },
      { name: 'SOLD_BY', value: 30, from: 'Product', to: 'Supplier' },
      { name: 'LOCATED_IN', value: 10, from: 'Location', to: 'Region' },
      { name: 'OWNED_BY', value: 8, from: 'Product', to: 'Manufacturer' },
      { name: 'DELIVERS_TO', value: 6, from: 'Delivery', to: 'Recipient' },
      { name: 'SERVICED_BY', value: 15, from: 'Service', to: 'Provider' },
      { name: 'ASSIGNED_TO', value: 12, from: 'Employee', to: 'Department' },
      { name: 'BELONGS_TO', value: 7, from: 'Product', to: 'Brand' },
      { name: 'MANUFACTURED_BY', value: 14, from: 'Product', to: 'Manufacturer' },
      { name: 'SUPPORTED_BY', value: 11, from: 'Service', to: 'Subscriber' },
      { name: 'UTILIZED_BY', value: 13, from: 'Service', to: 'Subscriber' },
      { name: 'ASSOCIATED_TO', value: 9, from: 'Product', to: 'Category' },
    ],
  },
};

export const northwindData = {
  args: {
    nodes: [
      { name: 'Customer', value: 85 },
      { name: 'Order', value: 406 },
      { name: 'Product', value: 17 },
      { name: 'Supplier', value: 10 },
      { name: 'Category', value: 2 },
    ],
    edges: [
      { name: 'PURCHASED', value: 406, from: 'Customer', to: 'Order' },
      { name: 'ORDERS', value: 500, from: 'Order', to: 'Product' },
      { name: 'PART_OF', value: 17, from: 'Product', to: 'Category' },
      { name: 'SUPPLIES', value: 17, from: 'Product', to: 'Supplier' },
    ],
  },
};
